VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package ssmsn

Package {ssmsn}


Type: Package
Title: Scale-Shape Mixtures of Skew-Normal Distributions
Version: 0.2.0
Date: 2017-01-31
Author: Rocio Maehara and Luis Benites
Maintainer: Luis Benites <lbenitesanchez@gmail.com>
Imports: MCMCpack
Description: It provides the density and random number generator for the Scale-Shape Mixtures of Skew-Normal Distributions proposed by Jamalizadeh and Lin (2016) <doi:10.1007/s00180-016-0691-1>.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Repository: CRAN
NeedsCompilation: no
Packaged: 2017-01-31 13:14:11 UTC; rmaehara
Date/Publication: 2017-02-01 08:34:50

Scale-Shape Mixtures of Skew-Normal Distributions

Description

It provides the density and random number generator.

Details

Package: ssmsn
Type: Package
Version: 0.2
Date: 2017-01-31
License: GPL (>=2)

Author(s)

Rocio Maehara rmaeharaa@gmail.com and Luis Benites lbenitesanchez@gmail.com

References

Jamalizadeh, Ahad and Lin, Tsung-I (2016). A general class of scale-shape mixtures of skew-normal distributions: properties and estimation. Computational Statistics, 1-24.

See Also

ssmsn,

Examples

#See examples for the ssmsn function linked above.

Scale-Shape Mixtures of Skew-Normal Distributions

Description

It provides the density and random number generator.

Usage

dssmsn(x, mu= NULL,sigma2= NULL,lambda= NULL,nu= NULL,family="skew.t.t")
rssmsn(n,mu= NULL,sigma2= NULL,lambda= NULL,nu= NULL,family="skew.t.t")

Arguments

x

vector of observations.

n

numbers of observations.

mu

location parameter.

sigma2

scale parameter.

lambda

skewness parameter.

nu

degree freedom

family

distribution family to be used in fitting ("skew.t.t", "skew.generalized.laplace.normal, "skew.slash.normal")

Details

As discussed in Jamalizadeh and Lin (2016) the scale-shape mixture of skew-normal (SSMSN) distribution admits the following conditioning-type stochasctic representation

Y=\mu + \sigma \tau_1^{-1/2}[Z_1 | (Z_2 < \lambda f^{-1/2} Z_1)],

where f = \tau_1/\tau_2 and (Z_1,Z_2) and (\tau_1,\tau_2) are independent. Alternatively the SSMSN distribution can be generated via the convolution-type stochastic representation, given by

Y=\mu + \sigma \left(\frac{\tau_1^{-1/2} f^{1/2}}{\sqrt{f + \lambda^2}}Z_2 + \frac{\lambda \tau_1^{-1/2}}{\sqrt{f + \lambda^2}}|Z_1|\right).

Value

dssmsn gives the density, rssmsn generates a random sample.

The length of the result is determined by n for rssmsn, and is the maximum of the lengths of the numerical arguments for the other functions dssmsn.

Author(s)

Rocio Maehara rmaeharaa@gmail.com and Luis Benites lbenitesanchez@gmail.com

References

Jamalizadeh, Ahad and Lin, Tsung-I (2016). A general class of scale-shape mixtures of skew-normal distributions: properties and estimation. Computational Statistics, 1-24.

Examples


rSTT  <- rssmsn(n=1000,mu=-4,sigma2=1,lambda=1,nu=c(3,4),"skew.t.t");hist(rSTT)
rSGLN <- rssmsn(n=1000,mu=-4,sigma2=1,lambda=1,nu=3,"skew.generalized.laplace.normal");hist(rSGLN)
rSSN  <- rssmsn(n=1000,mu=-4,sigma2=1,lambda=1,nu=3,"skew.slash.normal");hist(rSSN)

dSTT  <- dssmsn(0.5,mu=-4,sigma2=1,lambda=1,nu=c(3,4),"skew.t.t")
dSGLN <- dssmsn(0.5,mu=-4,sigma2=1,lambda=1,nu=3,"skew.generalized.laplace.normal")
dSSN  <- dssmsn(0.5,mu=-4,sigma2=1,lambda=1,nu=3,"skew.slash.normal")

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.